/**
 * @file Memsic2125.c Accelerometer implementation file
 * Copyright (c) 2009, Steve Denson
 * See end of file for MIT license terms.
 */
#include <propeller.h>
#include "Memsic2125.h"

/**
 * Get output pulse time
 * See header for api details.
 */
int m2125_getPulse(int pin)
{
    int rc = 0;
    int t0, t1;
    int mask = 1 << pin;
    asm("waitpne %mask, %mask");  // Wait For Pin To Go LOW
    asm("waitpeq %mask, %mask");  // Wait For Pin To Go HIGH
    t0 = CNT;                     // Store Current Counter Value
    asm("waitpne %mask, %mask");  // Wait For Pin To Go LOW 
    t1 = CNT;                     // Store New Counter Value
    rc = (ABS(t1 - t0) / (CLKFREQ / 2000000)) >> 1;
    return rc;  // Return Time in s
}

/**
 * Get output cycle time
 * See header for api details.
 */
int m2125_getCycle(int pin)
{
    int rc = 0;
    int t0, t1;
    int mask = 1 << pin;
    asm("waitpeq %mask, %mask");  // Wait For Pin To Go HIGH
    asm("waitpne %mask, %mask");  // Wait For Pin To Go LOW
    t0 = CNT;                     // Store Current Counter Value
    asm("waitpeq %mask, %mask");  // Wait For Pin To Go HIGH
    asm("waitpne %mask, %mask");  // Wait For Pin To Go LOW 
    t1 = CNT;                     // Store New Counter Value
    rc = (ABS(t1 - t0) / (CLKFREQ / 2000000)) >> 1;
    return rc;  // Return Time in s
}

/*
+------------------------------------------------------------------------------------------------------------------------------+
                                                   TERMS OF USE: MIT License                                                                                                              
+------------------------------------------------------------------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation     
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    
modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
is furnished to do so, subject to the following conditions:                                                                   
                                                                                                                              
The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
                                                                                                                              
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         
+------------------------------------------------------------------------------------------------------------------------------+
*/